@@ -26,6 +26,8 @@
 
 #include "menubar.h"
 #include "gtkhtml.h"
+#include "control-data.h"
+#include "properties.h"
 
 static void undo_cb             (GtkWidget *widget, GtkHTMLControlData *cd);
 static void redo_cb             (GtkWidget *widget, GtkHTMLControlData *cd);
@@ -41,18 +43,11 @@ static void replace_cb          (GtkWidget *widget, GtkHTMLControlData *cd);
 
 static void insert_image_cb     (GtkWidget *widget, GtkHTMLControlData *cd);
 static void insert_link_cb      (GtkWidget *widget, GtkHTMLControlData *cd);
+static void insert_rule_cb      (GtkWidget *widget, GtkHTMLControlData *cd);
+
+static void properties          (void);
 
 
-static GnomeUIInfo format_subtree_info[] = {
-	{ GNOME_APP_UI_TOGGLEITEM, N_("_Bold"), N_("Set selection to bold face"), NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_BOLD, 0, (GdkModifierType) 0, NULL },
-	{ GNOME_APP_UI_TOGGLEITEM, N_("_Italic"), N_("Set selection to italic face"), NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_ITALIC, 0, (GdkModifierType) 0, NULL },
-	{ GNOME_APP_UI_TOGGLEITEM, N_("_Underline"), N_("Set selection to underlined face"), NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_UNDERLINE, 0, (GdkModifierType) 0, NULL },
-	GNOMEUIINFO_END
-};
-
 static GnomeUIInfo edit_subtree_info[] = {
 	GNOMEUIINFO_MENU_UNDO_ITEM (undo_cb, NULL),
 	GNOMEUIINFO_MENU_REDO_ITEM (redo_cb, NULL),
@@ -65,19 +60,20 @@ static GnomeUIInfo edit_subtree_info[] = {
 	GNOMEUIINFO_ITEM_NONE (N_("Find Rege_x..."), N_("Regular expressions search..."), search_regex_cb),
 	GNOMEUIINFO_MENU_FIND_AGAIN_ITEM (search_next_cb, NULL),
 	GNOMEUIINFO_MENU_REPLACE_ITEM (replace_cb, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_PROPERTIES_ITEM (properties, NULL),
 	GNOMEUIINFO_END	
 };
 
 static GnomeUIInfo insert_subtree_info[] = {
 	GNOMEUIINFO_ITEM_NONE (N_("_Image..."), N_("Insert image into document..."), insert_image_cb),
 	GNOMEUIINFO_ITEM_NONE (N_("_Link..."), N_("Insert HTML link into document..."), insert_link_cb),
+	GNOMEUIINFO_ITEM_NONE (N_("_Rule..."),N_("Insert rule into document..."), insert_rule_cb),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo menu_info[] = {
-	GNOMEUIINFO_MENU_EDIT_TREE (edit_subtree_info),
 	GNOMEUIINFO_SUBTREE (N_("_Insert"), insert_subtree_info),
-	GNOMEUIINFO_SUBTREE (N_("F_ormat"), format_subtree_info),
 	GNOMEUIINFO_END
 };
 
@@ -140,13 +136,43 @@ replace_cb (GtkWidget *widget, GtkHTMLControlData *cd)
 static void
 insert_image_cb (GtkWidget *widget, GtkHTMLControlData *cd)
 {
-	image_insert (cd);
+	if (cd->properties_dialog)
+		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, TRUE);
+	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
+						   GTK_HTML_EDIT_PROPERTY_LINK, _("Insert image"),
+						   image_insertion,
+						   image_insert_cb,
+						   image_close_cb);
+	gtk_html_edit_properties_dialog_show (cd->properties_dialog);
 }
 
 static void
 insert_link_cb (GtkWidget *widget, GtkHTMLControlData *cd)
 {
-	link_insert (cd);
+	if (cd->properties_dialog)
+		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, FALSE);
+	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
+						   GTK_HTML_EDIT_PROPERTY_LINK, _("Link"),
+						   link_properties,
+						   link_apply_cb,
+						   link_close_cb);
+	gtk_html_edit_properties_dialog_show (cd->properties_dialog);
+}
+
+static void
+insert_rule_cb (GtkWidget *widget, GtkHTMLControlData *cd)
+{
+	rule_insert (cd);
+}
+
+static void
+properties (void)
+{
+	gchar *argv[2] = {"gtkhtml-properties-capplet", NULL};
+	if (gnome_execute_async (NULL, 1, argv) < 0)
+		gnome_error_dialog (_("Cannot execute gtkhtml properties"));
 }
 
 void
@@ -160,6 +186,10 @@ menubar_setup (BonoboUIHandler *uih,
 	g_return_if_fail (cd->html != NULL);
 	g_return_if_fail (GTK_IS_HTML (cd->html));
 
+	tree = bonobo_ui_handler_menu_parse_uiinfo_list_with_data (edit_subtree_info, cd);
+	bonobo_ui_handler_menu_add_list (uih, "/Edit", tree);
+	bonobo_ui_handler_menu_free_list (tree);
+
 	tree = bonobo_ui_handler_menu_parse_uiinfo_list_with_data (menu_info, cd);
 	bonobo_ui_handler_menu_add_list (uih, "/", tree);
 	bonobo_ui_handler_menu_free_list (tree);
