@@ -43,15 +43,14 @@ gtk_html_class_properties_destroy (GtkHTMLClassProperties *p)
 	g_free (p);
 }
 
+#ifdef GTKHTML_HAVE_GCONF
 #define GET(t,x,prop,f,c) \
         key = g_strconcat (GTK_HTML_GCONF_DIR, x, NULL); \
         val = gconf_client_get_full (client, key, NULL, FALSE, &dflt, NULL); \
-        if (val) { f; p-> ## prop = gconf_value_ ## t (val); c; \
+        if (val) { f; p-> ## prop = c gconf_value_ ## t (val); \
         gconf_value_destroy (val); } \
         g_free (key);
 
-#ifdef GTKHTML_HAVE_GCONF
-
 void
 gtk_html_class_properties_load (GtkHTMLClassProperties *p, GConfClient *client)
 {
@@ -63,9 +62,45 @@ gtk_html_class_properties_load (GtkHTMLClassProperties *p, GConfClient *client)
 
 	GET (bool, "/magic_links", magic_links,,);
 	GET (string, "/keybindings_theme", keybindings_theme,
-	     g_free (p->keybindings_theme), p->keybindings_theme = g_strdup (p->keybindings_theme));
+	     g_free (p->keybindings_theme), g_strdup);
 }
 
+#define SET(t,x,prop) \
+        { key = g_strconcat (GTK_HTML_GCONF_DIR, x, NULL); \
+        gconf_client_set_ ## t (client, key, p-> ## prop, NULL); \
+        g_free (key); }
+
+
+void
+gtk_html_class_properties_update (GtkHTMLClassProperties *p, GConfClient *client, GtkHTMLClassProperties *old)
+{
+	gchar *key;
+
+	if (p->magic_links != old->magic_links)
+		SET (bool, "/magic_links", magic_links);
+	SET (string, "/keybindings_theme", keybindings_theme);
+}
+
+#else
+void
+gtk_html_class_properties_load (GtkHTMLClassProperties *p)
+{
+	gnome_config_push_prefix (GTK_HTML_GNOME_CONFIG_PREFIX);
+	p->magic_links = gnome_config_get_bool ("magic_links=true");
+	p->keybindings_theme = gnome_config_get_string ("keybindings_theme=ms");
+	gnome_config_pop_prefix ();
+	gnome_config_sync ();
+}
+
+void
+gtk_html_class_properties_save (GtkHTMLClassProperties *p)
+{
+	gnome_config_push_prefix (GTK_HTML_GNOME_CONFIG_PREFIX);
+	gnome_config_set_bool ("magic_links", p->magic_links);
+	gnome_config_set_string ("keybindings_theme", p->keybindings_theme);
+	gnome_config_pop_prefix ();
+	gnome_config_sync ();
+}
 #endif
 
 void
@@ -77,29 +112,6 @@ gtk_html_class_properties_copy (GtkHTMLClassProperties *p1,
 	p1->keybindings_theme = g_strdup (p2->keybindings_theme);
 }
 
-#define SET(t,x,prop) \
-        key = g_strconcat (GTK_HTML_GCONF_DIR, x, NULL); \
-        gconf_client_set_ ## t (client, key, p-> ## prop, NULL); \
-        g_free (key);
-
-#ifdef GTKHTML_HAVE_GCONF
-
-void
-gtk_html_class_properties_update (GtkHTMLClassProperties *p, GConfClient *client, GtkHTMLClassProperties *old)
-{
-	gchar *key;
-
-	key = g_strconcat (GTK_HTML_GCONF_DIR, "/magic_links", NULL);
-
-	if (p->magic_links != old->magic_links) {
-		SET (bool, "/magic_links", magic_links);
-	}
-
-	SET (string, "/keybindings_theme", keybindings_theme);
-}
-
-#endif
-
 /* enums */
 
 static GtkEnumValue _gtk_html_cursor_skip_values[] = {
@@ -177,6 +189,12 @@ static GtkEnumValue _gtk_html_command_values[] = {
   { GTK_HTML_COMMAND_CAPITALIZE_WORD, "GTK_HTML_COMMAND_CAPITALIZE_WORD", "capitalize-word" },
   { GTK_HTML_COMMAND_UPCASE_WORD, "GTK_HTML_COMMAND_UPCASE_WORD", "upcase-word" },
   { GTK_HTML_COMMAND_DOWNCASE_WORD, "GTK_HTML_COMMAND_DOWNCASE_WORD", "downcase-word" },
+#ifdef GTKHTML_HAVE_PSPELL
+
+  { GTK_HTML_COMMAND_SPELL_SUGGEST, "GTK_HTML_COMMAND_SPELL_SUGGEST", "spell-suggest" },
+  { GTK_HTML_COMMAND_SPELL_PERSONAL_DICTIONARY_ADD, "GTK_HTML_COMMAND_SPELL_PERSONAL_DICTIONARY_ADD", "spell-personal-add" },
+  { GTK_HTML_COMMAND_SPELL_SESSION_DICTIONARY_ADD, "GTK_HTML_COMMAND_SPELL_SESSION_DICTIONARY_ADD", "spell-session-add" },
+#endif
   { 0, NULL, NULL }
 };
 
