@@ -152,6 +152,11 @@ enum _GtkHTMLCommandType {
 	GTK_HTML_COMMAND_CAPITALIZE_WORD,
 	GTK_HTML_COMMAND_UPCASE_WORD,
 	GTK_HTML_COMMAND_DOWNCASE_WORD,
+#ifdef GTKHTML_HAVE_PSPELL
+	GTK_HTML_COMMAND_SPELL_SUGGEST,
+	GTK_HTML_COMMAND_SPELL_PERSONAL_DICTIONARY_ADD,
+	GTK_HTML_COMMAND_SPELL_SESSION_DICTIONARY_ADD,
+#endif
 };
 typedef enum _GtkHTMLCommandType GtkHTMLCommandType;
 
@@ -169,6 +174,7 @@ typedef HTMLEngineSaveReceiverFn GtkHTMLSaveReceiverFn;
 struct _GtkHTML {
 	GtkLayout layout;
 
+	GtkWidget  *iframe_parent;
 	HTMLEngine *engine;
 
 	/* The URL of the link over which the pointer currently is.  NULL if
@@ -235,6 +241,10 @@ struct _GtkHTMLClass {
 	void (* cursor_move)          (GtkHTML *html, GtkDirectionType dir_type, GtkHTMLCursorSkipType skip);
 	void (* command)              (GtkHTML *html, GtkHTMLCommandType com_type);
 
+#ifdef GTKHTML_HAVE_PSPELL
+	void (* spell_suggestion_request) (GtkHTML *html, PspellManager *spell_checker, gchar *word);
+#endif
+
 	/* properties */
 	GtkHTMLClassProperties *properties;
 };
@@ -246,6 +256,10 @@ GtkType    gtk_html_get_type  (void);
 GtkWidget *gtk_html_new       (void);
 void       gtk_html_construct (GtkWidget *htmlw);
 
+/* parent iframe setting */
+void       gtk_html_set_iframe_parent       (GtkHTML *html,
+					     GtkWidget *parent);
+
 /* Debugging.  */
 void  gtk_html_enable_debug  (GtkHTML  *html,
 			      gboolean  debug);
