@@ -50,10 +50,10 @@ copy_forall (HTMLObject *obj,
 
 	data->size += size;
 
-	g_print ("Adding object %p [%s] to selection.\n",
-		 selection, html_type_name (HTML_OBJECT_TYPE (selection)));
+	/* g_print ("Adding object %p [%s] to selection. (%d)\n",
+		 selection, html_type_name (HTML_OBJECT_TYPE (selection)), size);
 	if (html_object_is_text (selection))
-		g_print ("\ttext `%s'\n", HTML_TEXT (selection)->text);
+	g_print ("\ttext `%s'\n", HTML_TEXT (selection)->text); */
 
 	data->buffer = g_list_prepend (data->buffer, selection);
 }
@@ -93,6 +93,8 @@ html_engine_copy (HTMLEngine *engine)
 	g_return_val_if_fail (engine->active_selection, 0);
 	g_return_val_if_fail (engine->clue != NULL, 0);
 
+	html_engine_edit_selection_updater_update_now (engine->selection_updater);
+
 	return copy (engine, &engine->cut_buffer);
 }
 
@@ -106,5 +108,7 @@ html_engine_copy_to_buffer (HTMLEngine *engine,
 	g_return_val_if_fail (engine->clue != NULL, 0);
 	g_return_val_if_fail (buffer != NULL, 0);
 
+	html_engine_edit_selection_updater_update_now (engine->selection_updater);
+
 	return copy (engine, buffer);
 }
