@@ -25,7 +25,6 @@
 #include "htmlclueflow.h"
 #include "htmltext.h"
 #include "htmltextmaster.h"
-#include "htmllinktext.h"
 #include "htmllinktextmaster.h"
 
 #include "htmlengine-edit.h"
@@ -345,6 +344,7 @@ do_insert (HTMLEngine *engine,
 
 		if (q == NULL) {
 			count = insert_chars (engine, p, len, style, color, url, target);
+			SPELL_CHECK (engine->cursor->object->parent, engine);
 			html_engine_move_cursor (engine, HTML_ENGINE_CURSOR_RIGHT, count);
 			insert_count += count;
 			break;
@@ -352,6 +352,7 @@ do_insert (HTMLEngine *engine,
 
 		if (q != p) {
 			count = insert_chars (engine, p, q - p, style, color, url, target);
+			SPELL_CHECK (engine->cursor->object->parent, engine);
 			html_engine_move_cursor (engine, HTML_ENGINE_CURSOR_RIGHT, count);
 			insert_count += count;
 		}
