@@ -24,13 +24,18 @@
 
 #include "htmlengine.h"
 
-void  html_engine_paste_buffer  (HTMLEngine *engine,
-				 GList      *buffer);
-void  html_engine_paste_object  (HTMLEngine *engine,
-				 HTMLObject *object,
-				 gboolean    undo);
+void  html_engine_paste_buffer     (HTMLEngine *engine,
+				    GList      *buffer);
+void  html_engine_paste_object     (HTMLEngine *engine,
+				    HTMLObject *object,
+				    gboolean    undo);
 
-void  html_engine_paste         (HTMLEngine *engine,
-				 gboolean    do_undo);
+void  html_engine_paste            (HTMLEngine *engine,
+				    gboolean    do_undo);
+
+void html_engine_replace_by_object (HTMLEngine *engine,
+				    HTMLObject *sobj, guint soff,
+				    HTMLObject *eobj, guint eoff,
+				    HTMLObject *new_obj);
 
 #endif /* _HTML_ENGINE_EDIT_PASTE_H */
