@@ -85,6 +85,13 @@ encode_entities (const guchar *input,
 	    *out++ = 'o';
 	    *out++ = 't';
 	    *out++ = ';';
+	} else if (*cur == 160) {
+		*out++ = '&';
+		*out++ = 'n';
+		*out++ = 'b';
+		*out++ = 's';
+		*out++ = 'p';
+		*out++ = ';';
 	} else if (((*cur >= 0x20) && (*cur < 0x80))
 		   || (*cur == '\n') || (*cur == '\r') || (*cur == '\t')) {
 	    /* Default case, just copy. */
@@ -255,7 +262,7 @@ html_engine_save (const HTMLEngine *engine,
 		return FALSE;
 	}
 
-	gtk_html_debug_dump_tree_simple (engine->clue, 1);
+	/* gtk_html_debug_dump_tree_simple (engine->clue, 1); */
 
 	state.engine = engine;
 	state.receiver = receiver;
@@ -289,7 +296,7 @@ html_engine_save_plain (const HTMLEngine *engine,
 		return FALSE;
 	}
 	
-	gtk_html_debug_dump_tree_simple (engine->clue, 1);
+	/* gtk_html_debug_dump_tree_simple (engine->clue, 1); */
 	
 	state.engine = engine;
 	state.receiver = receiver;
