@@ -26,7 +26,9 @@
 
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-
+#ifdef GTKHTML_HAVE_PSPELL
+#include <pspell/pspell.h>
+#endif
 
 typedef struct _HTMLEngine HTMLEngine;
 typedef struct _HTMLEngineClass HTMLEngineClass;
@@ -243,6 +245,12 @@ struct _HTMLEngine {
 	/* search & replace */
 	HTMLSearch  *search_info;
 	HTMLReplace *replace_info;
+
+#ifdef GTKHTML_HAVE_PSPELL
+	/* spell checking */
+	PspellConfig  *spell_config;
+	PspellManager *spell_checker;
+#endif
 };
 
 /* must be forward referenced *sigh* */
@@ -268,6 +276,8 @@ guint       html_engine_get_type      (void);
 HTMLEngine *html_engine_new           (GtkWidget *);
 void        html_engine_realize       (HTMLEngine *engine,
 				       GdkWindow  *window);
+void        html_engine_unrealize     (HTMLEngine *engine);
+
 
 /* Editability control.  */
 void      html_engine_set_editable  (HTMLEngine *e,
@@ -380,4 +390,14 @@ gint      html_engine_replaced                  (void);
 /* Magic links */
 void      html_engine_init_magic_links          (void);
 
+#ifdef GTKHTML_HAVE_PSPELL
+/* spell checking */
+void      html_engine_spell_check               (HTMLEngine *e);
+void      html_engine_spell_check_word          (HTMLEngine *e);
+gchar *   html_engine_get_word                  (HTMLEngine *e);
+gboolean  html_engine_word_is_valid             (HTMLEngine *e);
+void      html_engine_replace_word_with         (HTMLEngine *e,
+						 const gchar *word);
+#endif
+
 #endif /* _HTMLENGINE_H_ */
