@@ -74,9 +74,9 @@ struct _HTMLImage {
         HTMLImagePointer *image_ptr;
 	HTMLImageAnimation *animation;
 
-	GdkColor color;
-	gboolean color_allocated: 1;
-	gboolean have_color: 1;
+	HTMLColor *color;
+
+	guint have_color: 1;
 
 	gint8 border;
 
@@ -114,7 +114,7 @@ void        html_image_init        (HTMLImage        *image,
 				    gint16            height,
 				    gint8             percent,
 				    gint8             border,
-				    const GdkColor   *border_color,
+				    HTMLColor        *border_color,
 				    HTMLVAlignType    valign);
 HTMLObject *html_image_new         (HTMLImageFactory *imf,
 				    const gchar      *filename,
@@ -124,12 +124,12 @@ HTMLObject *html_image_new         (HTMLImageFactory *imf,
 				    gint16            height,
 				    gint8             percent,
 				    gint8             border,
-				    const GdkColor   *border_color,
+				    HTMLColor        *border_color,
 				    HTMLVAlignType    valign);
 
 void         html_image_set_size           (HTMLImage *image, gint w, gint percent, gint h);
 void         html_image_set_spacing        (HTMLImage *image, gint hspace, gint vspace);
-void         html_image_set_filename       (HTMLImage *image, const gchar *file);
+void         html_image_set_url            (HTMLImage *image, const gchar *url);
 void         html_image_set_valign         (HTMLImage *image, HTMLVAlignType valign);
 void         html_image_set_border         (HTMLImage *image, gint border);
 
