@@ -57,22 +57,24 @@ void        html_link_text_master_init          (HTMLLinkTextMaster      *link_t
 						 const gchar             *text,
 						 gint			  len,
 						 GtkHTMLFontStyle         font_style,
-						 const GdkColor          *color,
+						 HTMLColor               *color,
 						 const gchar             *url,
 						 const gchar             *target);
 HTMLObject *html_link_text_master_new           (const gchar             *text,
 						 GtkHTMLFontStyle         font_style,
-						 const GdkColor          *color,
+						 HTMLColor               *color,
 						 const gchar             *url,
 						 const gchar             *target);
 HTMLObject *html_link_text_master_new_with_len  (const gchar             *text,
 						 gint                     len,
 						 GtkHTMLFontStyle         font_style,
-						 const GdkColor          *color,
+						 HTMLColor               *color,
 						 const gchar             *url,
 						 const gchar             *target);
 
 void        html_link_text_master_set_url       (HTMLLinkTextMaster      *link,
 						 const gchar             *url);
 
+void        html_link_text_master_to_text       (HTMLLinkTextMaster *link,
+						 HTMLEngine *e);
 #endif /* _HTMLLINKTEXTMASTER_H_ */
