@@ -35,6 +35,11 @@ static HTMLObjectClass *parent_class = NULL;
 
 #define HT_CLASS(x) HTML_TEXT_CLASS (HTML_OBJECT (x)->klass)
 
+#ifdef GTKHTML_HAVE_PSPELL
+static SpellError * spell_error_new     (guint off, guint len);
+static void         spell_error_destroy (SpellError *se);
+#endif
+
 
 static void
 get_tags (const HTMLText *text,
@@ -58,57 +63,57 @@ get_tags (const HTMLText *text,
 
 	if (!html_color_equal (text->color, html_colorset_get_color (state->engine->settings->color_set, HTMLTextColor))
 	    && !html_color_equal (text->color, html_colorset_get_color (state->engine->settings->color_set, HTMLLinkColor))) {
-		opening_p += sprintf (opening_p, "<FONT COLOR=#%02x%02x%02x>",
+		opening_p += sprintf (opening_p, "<font color=#%02x%02x%02x>",
 				      text->color->color.red   >> 8,
 				      text->color->color.green >> 8,
 				      text->color->color.blue  >> 8);
-		ending_p += sprintf (ending_p, "</FONT>");
+		ending_p += sprintf (ending_p, "</font>");
 	}
 
 	size = font_style & GTK_HTML_FONT_STYLE_SIZE_MASK;
 	if (size != 0) {
-		opening_p += sprintf (opening_p, "<FONT SIZE=%d>", size);
+		opening_p += sprintf (opening_p, "<font size=%d>", size);
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_BOLD) {
-		opening_p += sprintf (opening_p, "<B>");
+		opening_p += sprintf (opening_p, "<b>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_ITALIC) {
-		opening_p += sprintf (opening_p, "<I>");
+		opening_p += sprintf (opening_p, "<i>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_UNDERLINE) {
-		opening_p += sprintf (opening_p, "<U>");
+		opening_p += sprintf (opening_p, "<u>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_STRIKEOUT) {
-		opening_p += sprintf (opening_p, "<S>");
+		opening_p += sprintf (opening_p, "<s>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_FIXED) {
-		opening_p += sprintf (opening_p, "<TT>");
-		ending_p += sprintf (ending_p, "</TT>");
+		opening_p += sprintf (opening_p, "<tt>");
+		ending_p += sprintf (ending_p, "</tt>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_STRIKEOUT) {
-		ending_p += sprintf (ending_p, "</S>");
+		ending_p += sprintf (ending_p, "</s>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_UNDERLINE) {
-		ending_p += sprintf (ending_p, "</U>");
+		ending_p += sprintf (ending_p, "</u>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_ITALIC) {
-		ending_p += sprintf (ending_p, "</I>");
+		ending_p += sprintf (ending_p, "</i>");
 	}
 
 	if (font_style & GTK_HTML_FONT_STYLE_BOLD) {
-		ending_p += sprintf (ending_p, "</B>");
+		ending_p += sprintf (ending_p, "</b>");
 	}
 
 	if (size != 0) {
-		ending_p += sprintf (ending_p, "</FONT SIZE=%d>", size);
+		ending_p += sprintf (ending_p, "</font size=%d>", size);
 	}
 
 
@@ -122,6 +127,8 @@ copy_helper (HTMLText *src,
 	     guint offset,
 	     gint len)
 {
+	GList *cur;
+
 	if (len < 0)
 		len = strlen (src->text);
 
@@ -131,6 +138,16 @@ copy_helper (HTMLText *src,
 	dest->font_style = src->font_style;
 	dest->color = src->color;
 	html_color_ref (dest->color);
+
+#ifdef GTKHTML_HAVE_PSPELL
+	dest->spell_errors = g_list_copy (src->spell_errors);
+	cur = dest->spell_errors;
+	while (cur) {
+		SpellError *se = (SpellError *) cur->data;
+		cur->data = spell_error_new (se->off, se->len);
+		cur = cur->next;
+	}
+#endif
 }
 
 
@@ -181,6 +198,109 @@ calc_size (HTMLObject *self,
 	return changed;
 }
 
+static gint
+calc_preferred_width (HTMLObject *self,
+		      HTMLPainter *painter)
+{
+	HTMLText *text;
+	GtkHTMLFontStyle font_style;
+
+	text = HTML_TEXT (self);
+	font_style = html_text_get_font_style (text);
+
+	return html_painter_calc_text_width (painter,
+					     text->text, text->text_len,
+					     font_style);
+}
+
+static gint
+forward_get_nb_width (HTMLText *text, HTMLPainter *painter, gboolean begin)
+{
+	HTMLObject *obj;
+
+	g_assert (text);
+	g_assert (html_object_is_text (HTML_OBJECT (text)));
+	g_assert (text->text_len == 0);
+
+	/* find prev/next object */
+	obj = (begin)
+		? html_object_prev_not_slave (HTML_OBJECT (text))
+		: html_object_next_not_slave (HTML_OBJECT (text));
+
+	/* if not found or not text return 0, otherwise forward get_nb_with there */
+	if (!obj || !html_object_is_text (obj))
+		return 0;
+	else
+		return html_text_get_nb_width (HTML_TEXT (obj), painter, begin);
+}
+
+/* return non-breakable text width on begin/end of this text */
+gint
+html_text_get_nb_width (HTMLText *text, HTMLPainter *painter, gboolean begin)
+{
+	gchar *t = text->text;
+
+	/* handle "" case */
+	if (text->text_len == 0)
+		return forward_get_nb_width (text, painter, begin);
+
+	/* if begins/ends with ' ' the width is 0 */
+	if ((begin && t [0] == ' ') || (!begin && t [text->text_len - 1] == ' '))
+		return 0;
+
+	/* find end/begin of nb text */
+	t = (begin) ? strchr (t, ' ') : strrchr (t, ' ');
+	if (!t)
+		return html_object_calc_preferred_width (HTML_OBJECT (text), painter);
+	return html_painter_calc_text_width (painter, (begin) ? text->text : t + 1,
+					     (begin) ? t - text->text : text->text_len - (t - text->text + 1),
+					     html_text_get_font_style (text));
+}
+
+static gint
+calc_min_width (HTMLObject *self,
+		HTMLPainter *painter)
+{
+	GtkHTMLFontStyle font_style;
+	HTMLObject *obj;
+	HTMLText *text;
+	gchar *t, *space;
+	gint w = 0, min_width = 0;
+
+	text       = HTML_TEXT (self);
+	font_style = html_text_get_font_style (text);
+	t          = text->text;
+
+	if (text->text_len == 0 || t [0] != ' ') {
+		obj = html_object_prev_not_slave (self);
+		w = (obj && html_object_is_text (obj)) ? html_text_get_nb_width (HTML_TEXT (obj), painter, FALSE) : 0;
+	}
+
+	if (text->text_len)
+		do {
+			space = strchr (t, ' ');
+			if (!space)
+				space = text->text + text->text_len;
+			w += html_painter_calc_text_width (painter, t, space - t, font_style);
+			t = (*space) ? space + 1 : space;
+			if (!(*t))
+				break;
+			if (w > min_width)
+				min_width = w;
+			w = 0;
+		} while (1);
+
+	if (text->text_len == 0 || text->text [text->text_len - 1] != ' ') {
+		obj = html_object_next_not_slave (self);
+		w += (obj && html_object_is_text (obj)) ? html_text_get_nb_width (HTML_TEXT (obj), painter, TRUE) : 0;
+	}
+
+	if (w > min_width)
+		min_width = w;
+
+	return min_width;
+}
+
 static void
 draw (HTMLObject *o,
       HTMLPainter *p,
@@ -567,6 +687,9 @@ destroy (HTMLObject *obj)
 {
 	HTMLText *text = HTML_TEXT (obj);
 	html_color_unref (text->color);
+#ifdef GTKHTML_HAVE_PSPELL
+	html_text_spell_errors_clear (text);
+#endif
 	g_free (text->text);
 	HTML_OBJECT_CLASS (parent_class)->destroy (obj);
 }
@@ -594,6 +717,8 @@ html_text_class_init (HTMLTextClass *klass,
 	object_class->draw = draw;
 	object_class->accepts_cursor = accepts_cursor;
 	object_class->calc_size = calc_size;
+	object_class->calc_preferred_width = calc_preferred_width;
+	object_class->calc_min_width = calc_min_width;
 	object_class->get_cursor = get_cursor;
 	object_class->get_cursor_base = get_cursor_base;
 	object_class->save = save;
@@ -647,6 +772,9 @@ html_text_init (HTMLText *text_object,
 	text_object->font_style = font_style;
 	html_color_ref (color);
 	text_object->color = color;
+#ifdef GTKHTML_HAVE_PSPELL
+	text_object->spell_errors = NULL;
+#endif
 }
 
 HTMLObject *
@@ -803,3 +931,41 @@ html_text_set_text (HTMLText *text, const gchar *new_text)
 	text->text = g_strdup (new_text);
 	html_object_change_set (HTML_OBJECT (text), HTML_CHANGE_ALL);
 }
+
+#ifdef GTKHTML_HAVE_PSPELL
+
+/* spell checking */
+
+
+static SpellError *
+spell_error_new (guint off, guint len)
+{
+	SpellError *se = g_new (SpellError, 1);
+
+	se->off = off;
+	se->len = len;
+
+	return se;
+}
+
+static void
+spell_error_destroy (SpellError *se)
+{
+	g_free (se);
+}
+
+void
+html_text_spell_errors_clear (HTMLText *text)
+{
+	g_list_foreach (text->spell_errors, (GFunc) spell_error_destroy, NULL);
+	g_list_free    (text->spell_errors);
+	text->spell_errors = NULL;
+}
+
+void
+html_text_spell_errors_add (HTMLText *text, guint off, guint len)
+{
+	text->spell_errors = g_list_append (text->spell_errors, spell_error_new (off, len));
+}
+
+#endif
